==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-sudo/lxqt-sudo_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>PasswordDialog</name>
    <message>
        <location filename="../../passworddialog.ui" line="20"/>
        <source>LXQt sudo</source>
        <translation>LXQt sudo</translation>
    </message>
    <message>
        <location filename="../../passworddialog.ui" line="77"/>
        <source>Command:</source>
        <translation>Εντολή:</translation>
    </message>
    <message>
        <location filename="../../passworddialog.ui" line="84"/>
        <source>Password:</source>
        <translation>Κωδικός πρόσβασης:</translation>
    </message>
    <message>
        <location filename="../../passworddialog.cpp" line="43"/>
        <source>&lt;b&gt;%1&lt;/b&gt; needs administrative privileges.
Please enter your password.</source>
        <translation>Το &lt;b&gt;%1&lt;/b&gt; απαιτεί προνόμια διαχειριστή.
Παρακαλώ εισαγάγετε τον κωδικό πρόσβασης.</translation>
    </message>
    <message>
        <location filename="../../passworddialog.cpp" line="54"/>
        <source>Attempt #%1</source>
        <translation>Προσπάθεια #%1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Usage: %1 command [arguments...]

GUI frontend for %2

Arguments:
  command        Command to run.
  arguments      Optional arguments for command.

</source>
        <translation>Χρήση: %1 εντολή [ορίσματα...]

Περιβάλλον συστήματος υποστήριξης του %2

Ορίσματα:
  εντολή           Η εντολή προς εκτέλεση.
  ορίσματα      Προαιρετικά ορίσματα για την εντολή.

</translation>
    </message>
    <message>
        <location filename="../../sudo.cpp" line="63"/>
        <source>Usage: %1 option [command [arguments...]]

GUI frontend for %2/%3

Arguments:
  option:
    -h|--help      Print this help.
    -v|--version   Print version information.
    -s|--su        Use %3(1) as backend.
    -d|--sudo      Use %2(8) as backend.
  command          Command to run.
  arguments        Optional arguments for command.

</source>
        <translation>Χρήση: %1 επιλογή [εντολή ορίσματα...]]

περιβάλλον συστήματος υποστήριξης για το %2/%3

Ορίσματα:
  επιλογή:
    -h|--help      Εκτύπωση της βοήθειας.
    -v|--version   Εκτύπωση της έκδοσης.
    -s|--su        Χρήση του %3(1) ως σύστημα υποστήριξης.
    -d|--sudo      Χρήση του %2(8) ως σύστημα υποστήριξης.
  εντολή          Εντολή προς εκτέλεση.
  ορίσματα        Προαιρετικά ορίσματα της εντολής.

</translation>
    </message>
    <message>
        <location filename="../../sudo.cpp" line="80"/>
        <source>%1 version %2
</source>
        <translation>%1 έκδοση %2
</translation>
    </message>
    <message>
        <source>%1: no command to run provided!</source>
        <translation>%1: δεν παρείχατε κάποια εντολή προς εκτέλεση!</translation>
    </message>
    <message>
        <source>Child &apos;%1&apos; process failed!
%2</source>
        <translation>Η θυγατρική διεργασία «%1» απέτυχε!
%2</translation>
    </message>
</context>
<context>
    <name>Sudo</name>
    <message>
        <location filename="../../sudo.cpp" line="135"/>
        <source>%1: no command to run provided!</source>
        <translation>%1: δεν παρείχατε κάποια εντολή προς εκτέλεση!</translation>
    </message>
    <message>
        <location filename="../../sudo.cpp" line="142"/>
        <source>%1: no backend chosen!</source>
        <translation>%1: δεν έχετε επιλέξει το σύστημα υποστήριξης!</translation>
    </message>
    <message>
        <location filename="../../sudo.cpp" line="147"/>
        <source>%1: warning - got multiple arguments for %2 backend, squashing into one: %3</source>
        <translation>%1: προειδοποίηση - ελήφθησαν πολλαπλά ορίσματα για το σύστημα υποστήριξης %2· διατήρηση του ενός: %3</translation>
    </message>
    <message>
        <location filename="../../sudo.cpp" line="162"/>
        <source>Failed to fork: %1</source>
        <translation>Αποτυχία δικράνωσης του: %1</translation>
    </message>
    <message>
        <location filename="../../sudo.cpp" line="205"/>
        <source>%1: Failed to exec &apos;%2&apos;: %3
</source>
        <translation>%1: Αποτυχία εκτέλεσης του «%2»: «%3»
</translation>
    </message>
    <message>
        <location filename="../../sudo.cpp" line="234"/>
        <source>Failed to set non-block: %1</source>
        <translation>Αποτυχία καθορισμού ως χωρίς φραγή: %1</translation>
    </message>
    <message>
        <location filename="../../sudo.cpp" line="242"/>
        <source>Failed to fdopen: %1</source>
        <translation>Αποτυχία εκτέλεσης fdopen για: %1</translation>
    </message>
    <message>
        <location filename="../../sudo.cpp" line="275"/>
        <source>Child &apos;%1&apos; process failed!
%2</source>
        <translation>Η θυγατρική διεργασία «%1» απέτυχε!
%2</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/lxqt-sudo/lxqt-sudo_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>PasswordDialog</name>
    <message>
        <location filename="../../passworddialog.ui" line="20"/>
        <source>LXQt sudo</source>
        <translation>LXQt sudo</translation>
    </message>
    <message>
        <location filename="../../passworddialog.ui" line="77"/>
        <source>Command:</source>
        <translation>Εντολή:</translation>
    </message>
    <message>
        <location filename="../../passworddialog.ui" line="84"/>
        <source>Password:</source>
        <translation>Κωδικός πρόσβασης:</translation>
    </message>
    <message>
        <location filename="../../passworddialog.cpp" line="43"/>
        <source>&lt;b&gt;%1&lt;/b&gt; needs administrative privileges.
Please enter your password.</source>
        <translation>Το &lt;b&gt;%1&lt;/b&gt; απαιτεί προνόμια διαχειριστή.
Παρακαλώ εισαγάγετε τον κωδικό πρόσβασης.</translation>
    </message>
    <message>
        <location filename="../../passworddialog.cpp" line="54"/>
        <source>Attempt #%1</source>
        <translation>Προσπάθεια #%1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Usage: %1 command [arguments...]

GUI frontend for %2

Arguments:
  command        Command to run.
  arguments      Optional arguments for command.

</source>
        <translation type="vanished">Χρήση: %1 εντολή [ορίσματα...]

Περιβάλλον συστήματος υποστήριξης του %2

Ορίσματα:
  εντολή           Η εντολή προς εκτέλεση.
  ορίσματα      Προαιρετικά ορίσματα για την εντολή.

</translation>
    </message>
    <message>
        <location filename="../../sudo.cpp" line="63"/>
        <source>Usage: %1 option [command [arguments...]]

GUI frontend for %2/%3

Arguments:
  option:
    -h|--help      Print this help.
    -v|--version   Print version information.
    -s|--su        Use %3(1) as backend.
    -d|--sudo      Use %2(8) as backend.
  command          Command to run.
  arguments        Optional arguments for command.

</source>
        <translation>Χρήση: %1 επιλογή [εντολή ορίσματα...]]

περιβάλλον συστήματος υποστήριξης για το %2/%3

Ορίσματα:
  επιλογή:
    -h|--help      Εκτύπωση της βοήθειας.
    -v|--version   Εκτύπωση της έκδοσης.
    -s|--su        Χρήση του %3(1) ως σύστημα υποστήριξης.
    -d|--sudo      Χρήση του %2(8) ως σύστημα υποστήριξης.
  εντολή          Εντολή προς εκτέλεση.
  ορίσματα        Προαιρετικά ορίσματα της εντολής.

</translation>
    </message>
    <message>
        <location filename="../../sudo.cpp" line="80"/>
        <source>%1 version %2
</source>
        <translation>%1 έκδοση %2
</translation>
    </message>
    <message>
        <source>%1: no command to run provided!</source>
        <translation type="vanished">%1: δεν παρείχατε κάποια εντολή προς εκτέλεση!</translation>
    </message>
    <message>
        <source>Child &apos;%1&apos; process failed!
%2</source>
        <translation type="vanished">Η θυγατρική διεργασία «%1» απέτυχε!
%2</translation>
    </message>
</context>
<context>
    <name>Sudo</name>
    <message>
        <location filename="../../sudo.cpp" line="135"/>
        <source>%1: no command to run provided!</source>
        <translation>%1: δεν παρείχατε κάποια εντολή προς εκτέλεση!</translation>
    </message>
    <message>
        <location filename="../../sudo.cpp" line="142"/>
        <source>%1: no backend chosen!</source>
        <translation>%1: δεν έχετε επιλέξει το σύστημα υποστήριξης!</translation>
    </message>
    <message>
        <location filename="../../sudo.cpp" line="147"/>
        <source>%1: warning - got multiple arguments for %2 backend, squashing into one: %3</source>
        <translation>%1: προειδοποίηση - ελήφθησαν πολλαπλά ορίσματα για το σύστημα υποστήριξης %2· διατήρηση του ενός: %3</translation>
    </message>
    <message>
        <location filename="../../sudo.cpp" line="162"/>
        <source>Failed to fork: %1</source>
        <translation>Αποτυχία δικράνωσης του: %1</translation>
    </message>
    <message>
        <location filename="../../sudo.cpp" line="205"/>
        <source>%1: Failed to exec &apos;%2&apos;: %3
</source>
        <translation>%1: Αποτυχία εκτέλεσης του «%2»: «%3»
</translation>
    </message>
    <message>
        <location filename="../../sudo.cpp" line="234"/>
        <source>Failed to set non-block: %1</source>
        <translation>Αποτυχία καθορισμού ως χωρίς φραγή: %1</translation>
    </message>
    <message>
        <location filename="../../sudo.cpp" line="242"/>
        <source>Failed to fdopen: %1</source>
        <translation>Αποτυχία εκτέλεσης fdopen για: %1</translation>
    </message>
    <message>
        <location filename="../../sudo.cpp" line="275"/>
        <source>Child &apos;%1&apos; process failed!
%2</source>
        <translation>Η θυγατρική διεργασία «%1» απέτυχε!
%2</translation>
    </message>
</context>
</TS>
